==> styled-components-2.0.0-8.tgz: package/lib/constructors/test/injectGlobal.test.js <==
'use strict';

var _templateObject = _taggedTemplateLiteral(['\n      html {\n        ', '\n      }\n    '], ['\n      html {\n        ', '\n      }\n    ']),
    _templateObject2 = _taggedTemplateLiteral(['\n      a {\n        ', '\n      }\n    '], ['\n      a {\n        ', '\n      }\n    ']),
    _templateObject3 = _taggedTemplateLiteral(['\n      ', '\n    '], ['\n      ', '\n    ']);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _enzyme = require('enzyme');

var _injectGlobal = require('../injectGlobal');

var _injectGlobal2 = _interopRequireDefault(_injectGlobal);

var _StyleSheet = require('../../models/StyleSheet');

var _StyleSheet2 = _interopRequireDefault(_StyleSheet);

var _utils = require('../../test/utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

var styled = (0, _utils.resetStyled)();
var rule1 = 'width: 100%;';
var rule2 = 'text-decoration: none;';
var rule3 = 'color: blue;';

describe('injectGlobal', function () {
  beforeEach(function () {
    (0, _utils.resetStyled)();
  });

  it('should inject rules into the head', function () {
    (0, _injectGlobal2.default)(_templateObject, rule1);
    (0, _expect2.default)(_StyleSheet2.default.injected).toBe(true);
  });

  it('should non-destructively inject styles when called repeatedly', function () {
    (0, _injectGlobal2.default)(_templateObject, rule1);

    (0, _injectGlobal2.default)(_templateObject2, rule2);
    (0, _utils.expectCSSMatches)('\n      html {\n        ' + rule1 + '\n      }\n      a {\n        ' + rule2 + '\n      }\n    ');
  });

  it('should non-destructively inject styles when called after a component', function () {
    var Comp = styled.div(_templateObject3, rule3);
    (0, _enzyme.shallow)(_react2.default.createElement(Comp, null));

    (0, _injectGlobal2.default)(_templateObject, rule1);

    (0, _utils.expectCSSMatches)('\n      .sc-a {}\n      .b {\n        ' + rule3 + '\n      }\n      html {\n        ' + rule1 + '\n      }\n    ');
  });
});

==> styled-components-2.0.0-12.tgz: package/lib/constructors/test/injectGlobal.test.js <==
'use strict';

var _templateObject = _taggedTemplateLiteral(['\n      html {\n        ', '\n      }\n    '], ['\n      html {\n        ', '\n      }\n    ']),
    _templateObject2 = _taggedTemplateLiteral(['\n      a {\n        ', '\n      }\n    '], ['\n      a {\n        ', '\n      }\n    ']),
    _templateObject3 = _taggedTemplateLiteral(['\n      ', '\n    '], ['\n      ', '\n    ']);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _enzyme = require('enzyme');

var _injectGlobal2 = require('../injectGlobal');

var _injectGlobal3 = _interopRequireDefault(_injectGlobal2);

var _StyleSheet = require('../../models/StyleSheet');

var _StyleSheet2 = _interopRequireDefault(_StyleSheet);

var _GlobalStyle2 = require('../../models/GlobalStyle');

var _GlobalStyle3 = _interopRequireDefault(_GlobalStyle2);

var _flatten = require('../../utils/flatten');

var _flatten2 = _interopRequireDefault(_flatten);

var _stringifyRules = require('../../utils/stringifyRules');

var _stringifyRules2 = _interopRequireDefault(_stringifyRules);

var _css = require('../css');

var _css2 = _interopRequireDefault(_css);

var _utils = require('../../test/utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

var injectGlobal = (0, _injectGlobal3.default)((0, _GlobalStyle3.default)(_flatten2.default, _stringifyRules2.default), _css2.default);

var styled = (0, _utils.resetStyled)();
var rule1 = 'width: 100%;';
var rule2 = 'text-decoration: none;';
var rule3 = 'color: blue;';

describe('injectGlobal', function () {
  beforeEach(function () {
    (0, _utils.resetStyled)();
  });

  it('should inject rules into the head', function () {
    injectGlobal(_templateObject, rule1);
    (0, _expect2.default)(_StyleSheet2.default.injected).toBe(true);
  });

  it('should non-destructively inject styles when called repeatedly', function () {
    injectGlobal(_templateObject, rule1);

    injectGlobal(_templateObject2, rule2);
    (0, _utils.expectCSSMatches)('\n      html {\n        ' + rule1 + '\n      }\n      a {\n        ' + rule2 + '\n      }\n    ');
  });

  it('should non-destructively inject styles when called after a component', function () {
    var Comp = styled.div(_templateObject3, rule3);
    (0, _enzyme.shallow)(_react2.default.createElement(Comp, null));

    injectGlobal(_templateObject, rule1);

    (0, _utils.expectCSSMatches)('\n      .sc-a {}\n      .b {\n        ' + rule3 + '\n      }\n      html {\n        ' + rule1 + '\n      }\n    ');
  });
});
